# Generated by Django 4.2.16 on 2024-10-13 08:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("hope_smart_import", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="configuration",
            name="mapping",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
