.align-center {
  align-content: center;
  text-align: center;
  width: 100%;
}

.md-typeset__table {
  width: 100%;
}

.md-typeset__table table:not([class]) {
  display: table;
}

/*# sourceMappingURL=style.css.map */
