# Generated by Django 4.2.16 on 2024-10-03 09:03

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("hope_flex_fields", "0002_fieldset_content_type"),
    ]

    operations = [
        migrations.CreateModel(
            name="Configuration",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=100, unique=True)),
                (
                    "checker",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="hope_flex_fields.datachecker"),
                ),
            ],
        ),
    ]
