# from smart_env import SmartEnv
#
# CONFIG = {
#     "CELERY_VISIBILITY_TIMEOUT": (
#         int,
#         60,
#         60,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#debug",
#     ),
#     "CELERY_TASK_ALWAYS_EAGER": (
#         bool,
#         True,
#         False,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#debug",
#     ),
#     "CELERY_TASK_EAGER_PROPAGATES": (
#         bool,
#         True,
#         False,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#debug",
#     ),
#     "DEBUG": (
#         bool,
#         False,
#         True,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#debug",
#     ),
#     "CELERY_BROKER_URL": (
#         str,
#         "redis://localhost:6379/0",
#         "",
#         True,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#DATABASES",
#     ),
#     "USE_TZ": (
#         bool,
#         True,
#         True,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#debug",
#     ),
#     "SECURE_SSL_REDIRECT": (
#         bool,
#         True,
#         False,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#SECURE_SSL_REDIRECT",
#     ),
#     "SESSION_COOKIE_SECURE": (
#         bool,
#         True,
#         False,
#         False,
#         "https://docs.djangoproject.com/en/5.1/ref/settings/#SESSION_COOKIE_SECURE",
#     ),
#     "SECRET_KEY": (str, "", "", True, "Django SECRET_KEY"),
# }
#
# env = SmartEnv(**CONFIG)
